@@ -6,7 +6,7 @@ use crate::tag::{TagFilter, TagFilterGroup};
 use crate::util;
 use crate::{impl_de_by_from_str, impl_ser_by_to_string};
 use colored::Color;
-use fxhash::FxHashMap as HashMap;
+use fxhash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use handlebars::Handlebars;
 use serde::{Deserialize, Serialize};
 use std::path::{Path, PathBuf};
@@ -97,7 +97,7 @@ pub struct Config {
     pub tag_filters: Vec<NamedTagFilter>,
     #[serde(default, skip_serializing_if = "HashMap::is_empty")]
     pub alias: HashMap<String, Alias>,
-    pub categories: HashMap<ScriptType, ScriptTypeConfig>,
+    pub types: HashMap<ScriptType, ScriptTypeConfig>,
     #[serde(default, skip_serializing_if = "HashMap::is_empty")]
     pub env: HashMap<String, String>,
     #[serde(skip)]
@@ -136,7 +136,7 @@ impl Default for Config {
                 },
             ],
             main_tag_filter: "+all".parse().unwrap(),
-            categories: ScriptTypeConfig::default_script_types(),
+            types: ScriptTypeConfig::default_script_types(),
             alias: std::array::IntoIter::new([
                 gen_alias("la", &["ls", "-a"]),
                 gen_alias("ll", &["ls", "-l"]),
@@ -260,18 +260,19 @@ impl Config {
         Ok(Color::from(c))
     }
     pub fn get_script_conf(&self, ty: &ScriptType) -> Result<&ScriptTypeConfig> {
-        self.categories
+        self.types
             .get(ty)
             .ok_or_else(|| Error::UnknownType(ty.to_string()))
     }
-    pub fn get_tag_filter_group(&self) -> TagFilterGroup {
+    pub fn get_tag_filter_group(&self, toggle: &mut HashSet<String>) -> TagFilterGroup {
         let mut group = TagFilterGroup::default();
         for f in self.tag_filters.iter() {
-            if f.inactivated {
+            let inactivated = f.inactivated ^ toggle.remove(&f.name);
+            if inactivated {
                 log::debug!("{:?} 未啟用", f);
                 continue;
             }
-            group.push(f.content.clone());
+            group.push(f.content.clone()); // TODO: TagFilterGroup 可以多帶點 lifetime 減少複製
         }
         group.push(self.main_tag_filter.clone());
         group
