@@ -8,13 +8,13 @@ pub enum SysPath {
 }
 #[derive(Debug, Clone, Copy, Eq, PartialEq)]
 pub enum FormatCode {
+    PromptLevel,
     Config,
     ScriptName,
     Regex,
     RangeQuery,
     ScriptQuery,
     Tag,
-    FilterQuery,
     NonEmptyArray,
 }
 
@@ -98,7 +98,6 @@ impl<T, E: 'static + Send + Sync + std::error::Error> Contextable<T> for std::re
 #[derive(Debug, Clone)]
 pub enum RedundantOpt {
     Scripts(Vec<String>),
-    CommandArgs,
     Type,
     Tag,
     Filter,
